package com.example.daniel_taskshome

import androidx.compose.ui.tooling.preview.Preview
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material.*
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.Alignment
import kotlin.math.pow

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            BMICalculatorApp()
        }
    }
}

@Composable
fun BMICalculatorApp() {
    var weight by remember { mutableStateOf("") }
    var height by remember { mutableStateOf("") }
    var isUSC by remember { mutableStateOf(false) }
    var bmiResult by remember { mutableStateOf<Double?>(null) }
    var bmiCategory by remember { mutableStateOf("") }

    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.Top,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Text("BMI Calculator", fontSize = 24.sp, modifier = Modifier.padding(bottom = 16.dp))

        OutlinedTextField(
            value = weight,
            onValueChange = { weight = it },
            label = { Text("Weight (${if (isUSC) "lbs" else "kg"})") },
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
            modifier = Modifier.fillMaxWidth()
        )

        Spacer(modifier = Modifier.height(8.dp))

        OutlinedTextField(
            value = height,
            onValueChange = { height = it },
            label = { Text("Height (${if (isUSC) "inches" else "meters"})") },
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
            modifier = Modifier.fillMaxWidth()
        )

        Spacer(modifier = Modifier.height(16.dp))

        Row(
            verticalAlignment = Alignment.CenterVertically,
            modifier = Modifier.fillMaxWidth()
        ) {
            Text("Use US Customary Units (USC)")
            Switch(checked = isUSC, onCheckedChange = { isUSC = it })
        }

        Spacer(modifier = Modifier.height(16.dp))

        Button(onClick = {
            bmiResult = calculateBMI(weight, height, isUSC)
            bmiCategory = getBMICategory(bmiResult)
        }) {
            Text("Calculate BMI")
        }

        Spacer(modifier = Modifier.height(16.dp))

        bmiResult?.let {
            Text("Your BMI: %.2f".format(it), fontSize = 20.sp)
            Text("Category: $bmiCategory", fontSize = 16.sp)
        }
    }
}

fun calculateBMI(weight: String, height: String, isUSC: Boolean): Double? {
    val weightValue = weight.toDoubleOrNull()
    val heightValue = height.toDoubleOrNull()
    if (weightValue != null && heightValue != null) {
        return if (isUSC) {
            703 * (weightValue / heightValue.pow(2))
        } else {
            weightValue / (heightValue.pow(2))
        }
    }
    return null
}

fun getBMICategory(bmi: Double?): String {
    return when {
        bmi == null -> ""
        bmi < 18.5 -> "Underweight"
        bmi < 24.9 -> "Normal weight"
        bmi < 29.9 -> "Overweight"
        else -> "Obesity"
    }
}

@Preview(showBackground = true)
@Composable
fun BMICalculatorPreview() {
    BMICalculatorApp()
}

